]> git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
replaced sv_clmovement_waitforinput with sv_clmovement_inputtimeout
authorhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Wed, 1 Apr 2009 18:16:13 +0000 (18:16 +0000)
committerhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Wed, 1 Apr 2009 18:16:13 +0000 (18:16 +0000)
which takes a timeout inseconds rather than frames, this makes
sys_ticrate safer to modify in Nexuiz (which has a low cl_netfps that
breaks with a rapid sys_ticrate if the administrator tries that)

git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@8842 d7cf8633-e32d-0410-b094-e92efae38249

darkplaces.txt
server.h
sv_main.c
sv_phys.c
sv_user.c

index fc096d7f1f3b8ab1fa18a58d307b21d0394e8e74..7873f233d922fdd2e185159372813394957cc10d 100644 (file)
@@ -858,7 +858,7 @@ sv_cheats                                         0                   enables ch
 sv_clmovement_enable                              1                   whether to allow clients to use cl_movement prediction, which can cause choppy movement on the server which may annoy other players\r
 sv_clmovement_minping                             0                   if client ping is below this time in milliseconds, then their ability to use cl_movement prediction is disabled for a while (as they don't need it)\r
 sv_clmovement_minping_disabletime                 1000                when client falls below minping, disable their prediction for this many milliseconds (should be at least 1000 or else their prediction may turn on/off frequently)\r
-sv_clmovement_waitforinput                        16                  when a client does not send input for this many frames, force them to move anyway (unlike QuakeWorld)\r
+sv_clmovement_inputtimeout                        0.2                 when a client does not send input for this many seconds, force them to move anyway (unlike QuakeWorld)\r
 sv_cullentities_nevercullbmodels                  0                   if enabled the clients are always notified of moving doors and lifts and other submodels of world (warning: eats a lot of network bandwidth on some levels!)\r
 sv_cullentities_pvs                               1                   fast but loose culling of hidden entities\r
 sv_cullentities_stats                             0                   displays stats on network entities culled by various methods for each client\r
index 835c9f867d06b3599ca0852205947a6aa2ab220d..555bef607a82b9ee3c5cc57bfce15e2f0b9773e6 100644 (file)
--- a/server.h
+++ b/server.h
@@ -212,8 +212,8 @@ typedef struct client_s
 
        // this is used by sv_clmovement_minping code
        double clmovement_disabletimeout;
-       // this is used by sv_clmvoement_waitforinput code
-       int clmovement_skipphysicsframes;
+       // this is used by sv_clmovement_inputtimeout code
+       float clmovement_inputtimeout;
 
 // spawn parms are carried from level to level
        float spawn_parms[NUM_SPAWN_PARMS];
@@ -378,7 +378,7 @@ extern cvar_t sv_checkforpacketsduringsleep;
 extern cvar_t sv_clmovement_enable;
 extern cvar_t sv_clmovement_minping;
 extern cvar_t sv_clmovement_minping_disabletime;
-extern cvar_t sv_clmovement_waitforinput;
+extern cvar_t sv_clmovement_inputtimeout;
 extern cvar_t sv_cullentities_nevercullbmodels;
 extern cvar_t sv_cullentities_pvs;
 extern cvar_t sv_cullentities_stats;
index 671981602cc687e4150b8de369f0e7bee1f25abb..9fc0661004259b8519066c30c04eefeeda4e625f 100644 (file)
--- a/sv_main.c
+++ b/sv_main.c
@@ -60,7 +60,7 @@ cvar_t sv_checkforpacketsduringsleep = {0, "sv_checkforpacketsduringsleep", "0",
 cvar_t sv_clmovement_enable = {0, "sv_clmovement_enable", "1", "whether to allow clients to use cl_movement prediction, which can cause choppy movement on the server which may annoy other players"};
 cvar_t sv_clmovement_minping = {0, "sv_clmovement_minping", "0", "if client ping is below this time in milliseconds, then their ability to use cl_movement prediction is disabled for a while (as they don't need it)"};
 cvar_t sv_clmovement_minping_disabletime = {0, "sv_clmovement_minping_disabletime", "1000", "when client falls below minping, disable their prediction for this many milliseconds (should be at least 1000 or else their prediction may turn on/off frequently)"};
-cvar_t sv_clmovement_waitforinput = {0, "sv_clmovement_waitforinput", "4", "when a client does not send input for this many frames, force them to move anyway (unlike QuakeWorld)"};
+cvar_t sv_clmovement_inputtimeout = {0, "sv_clmovement_inputtimeout", "0.2", "when a client does not send input for this many seconds, force them to move anyway (unlike QuakeWorld)"};
 cvar_t sv_cullentities_nevercullbmodels = {0, "sv_cullentities_nevercullbmodels", "0", "if enabled the clients are always notified of moving doors and lifts and other submodels of world (warning: eats a lot of network bandwidth on some levels!)"};
 cvar_t sv_cullentities_pvs = {0, "sv_cullentities_pvs", "1", "fast but loose culling of hidden entities"};
 cvar_t sv_cullentities_stats = {0, "sv_cullentities_stats", "0", "displays stats on network entities culled by various methods for each client"};
@@ -337,7 +337,7 @@ void SV_Init (void)
        Cvar_RegisterVariable (&sv_clmovement_enable);
        Cvar_RegisterVariable (&sv_clmovement_minping);
        Cvar_RegisterVariable (&sv_clmovement_minping_disabletime);
-       Cvar_RegisterVariable (&sv_clmovement_waitforinput);
+       Cvar_RegisterVariable (&sv_clmovement_inputtimeout);
        Cvar_RegisterVariable (&sv_cullentities_nevercullbmodels);
        Cvar_RegisterVariable (&sv_cullentities_pvs);
        Cvar_RegisterVariable (&sv_cullentities_stats);
index 7300cbd65b3a4399a56823ca4a52b4a5f15d5269..591c2baf933c6e367e3a82d27f82857e09a6f07a 100644 (file)
--- a/sv_phys.c
+++ b/sv_phys.c
@@ -2225,7 +2225,7 @@ void SV_Physics_ClientEntity(prvm_edict_t *ent)
        }
 
        // don't run physics here if running asynchronously
-       if (host_client->clmovement_skipphysicsframes <= 0)
+       if (host_client->clmovement_inputtimeout <= 0)
        {
                SV_ClientThink();
                //host_client->cmd.time = max(host_client->cmd.time, sv.time);
@@ -2272,7 +2272,7 @@ void SV_Physics_ClientEntity(prvm_edict_t *ent)
        case MOVETYPE_WALK:
                SV_RunThink (ent);
                // don't run physics here if running asynchronously
-               if (host_client->clmovement_skipphysicsframes <= 0)
+               if (host_client->clmovement_inputtimeout <= 0)
                        SV_WalkMove (ent);
                break;
        case MOVETYPE_TOSS:
@@ -2294,8 +2294,10 @@ void SV_Physics_ClientEntity(prvm_edict_t *ent)
 
        // decrement the countdown variable used to decide when to go back to
        // synchronous physics
-       if (host_client->clmovement_skipphysicsframes > 0)
-               host_client->clmovement_skipphysicsframes--;
+       if (host_client->clmovement_inputtimeout > sv.frametime)
+               host_client->clmovement_inputtimeout -= sv.frametime;
+       else
+               host_client->clmovement_inputtimeout = 0;
 
        SV_CheckVelocity (ent);
 
index ffa9c3997fee92ff26fe757446c59bf5e45484a1..ec6f7a18c14d1c375e129fdaec6a362ade5fd7bb 100644 (file)
--- a/sv_user.c
+++ b/sv_user.c
@@ -567,7 +567,7 @@ void SV_ExecuteClientMoves(void)
        if (ceil(max(sv_readmoves[sv_numreadmoves-1].receivetime - sv_readmoves[sv_numreadmoves-1].time, 0) * 1000.0) < sv_clmovement_minping.integer)
                host_client->clmovement_disabletimeout = realtime + sv_clmovement_minping_disabletime.value / 1000.0;
        // several conditions govern whether clientside movement prediction is allowed
-       if (sv_readmoves[sv_numreadmoves-1].sequence && sv_clmovement_enable.integer && sv_clmovement_waitforinput.integer > 0 && host_client->clmovement_disabletimeout <= realtime && host_client->edict->fields.server->movetype == MOVETYPE_WALK && (!(val = PRVM_EDICTFIELDVALUE(host_client->edict, prog->fieldoffsets.disableclientprediction)) || !val->_float))
+       if (sv_readmoves[sv_numreadmoves-1].sequence && sv_clmovement_enable.integer && sv_clmovement_inputtimeout.value > 0 && host_client->clmovement_disabletimeout <= realtime && host_client->edict->fields.server->movetype == MOVETYPE_WALK && (!(val = PRVM_EDICTFIELDVALUE(host_client->edict, prog->fieldoffsets.disableclientprediction)) || !val->_float))
        {
                // process the moves in order and ignore old ones
                // but always trust the latest move
@@ -585,7 +585,7 @@ void SV_ExecuteClientMoves(void)
                                // this is a new move
                                move->time = bound(sv.time - 1, move->time, sv.time); // prevent slowhack/speedhack combos
                                move->time = max(move->time, host_client->cmd.time); // prevent backstepping of time
-                               moveframetime = bound(0, move->time - host_client->cmd.time, min(0.1, sv.frametime * sv_clmovement_waitforinput.integer));
+                               moveframetime = bound(0, move->time - host_client->cmd.time, min(0.1, sv_clmovement_inputtimeout.value));
                                //Con_Printf("movesequence = %i (%i lost), moveframetime = %f\n", move->sequence, move->sequence ? move->sequence - host_client->movesequence - 1 : 0, moveframetime);
                                host_client->cmd = *move;
                                host_client->movesequence = move->sequence;
@@ -595,7 +595,7 @@ void SV_ExecuteClientMoves(void)
                                // (they can't go beyond the current time so there is no cheat issue
                                //  with this approach, and if they don't send input for a while they
                                //  start moving anyway, so the longest 'lagaport' possible is
//  determined by the sv_clmovement_waitforinput cvar)
                                if (moveframetime <= 0)
                                        continue;
                                oldframetime = prog->globals.server->frametime;
@@ -613,7 +613,7 @@ void SV_ExecuteClientMoves(void)
                                SV_Physics_ClientMove();
                                sv.frametime = oldframetime2;
                                prog->globals.server->frametime = oldframetime;
-                               host_client->clmovement_skipphysicsframes = sv_clmovement_waitforinput.integer;
+                               host_client->clmovement_inputtimeout = sv_clmovement_inputtimeout.value;
                        }
                }
        }
@@ -641,7 +641,7 @@ void SV_ExecuteClientMoves(void)
                        // time
                host_client->movesequence = 0;
                // make sure that normal physics takes over immediately
-               host_client->clmovement_skipphysicsframes = 0;
+               host_client->clmovement_inputtimeout = 0;
        }
 
        // calculate average ping time
@@ -595,7 +595,7 @@ void SV_ExecuteClientMoves(void)
                                //  with this approach, and if they don't send input for a while they
                                //  start moving anyway, so the longest 'lagaport' possible is
-                               //  determined by the sv_clmovement_waitforinput cvar)
+                               //  determined by the sv_clmovement_inputtimeout cvar)
                                if (moveframetime <= 0)
                                        continue;